meta_package_manager.platform module — Meta Package Manager 2.4.0 documentation

# meta_package_manager.platform module

Helpers and utilities to handle platform idiosyncracies.

`meta_package_manager.platform.` `is_linux`()

  Return True only if current platform is Linux.

`meta_package_manager.platform.` `is_macos`()

  Return True only if current platform is macOS.

`meta_package_manager.platform.` `is_windows`()

  Return True only if current platform is Windows.

`meta_package_manager.platform.` `current_os`()

  Return ID and label of current OS.

`meta_package_manager.platform.` `os_label`(os_id)

  Return platform label for user-friendly output.